# -*- coding: utf-8 -*-
import logging
import xmlrpc.client

_logger = logging.getLogger(__name__)


class Connection(object):
    
    def __init__(self, url):
        self._url = url
        self._common = xmlrpc.client.ServerProxy('{}/xmlrpc/2/common'.format(self._url))

    def trasmit(self, method, *args, **kwargs):
        try:
            response = getattr(self._common, method)(*args)
            _logger.info("Response of method '{}' ⭢ {}".format(method, response))
            return response
        except xmlrpc.client.ProtocolError as err:
            _logger.error(err)

    def authenticate(self, db, user, password, session={}):
        response = self.trasmit('authenticate', db, user, password, session)
        return response



from odooapiclient.client import Client


client = Client(host='andriisem.odoo.com', dbname='andriisem', saas=True)
client.authenticate(login='semko.andrey.i@gmail.com', pwd='audi100')
print(client._uid)


from . import auth


class Client(object):
    
    def __init__(self, protocol='http', host='localhost', port=8069, dbname=None, ssl=False):
        if ssl:
            protocol, port = 'https', 443
        
        self._host = host
        self._port = port
        self._db = dbname
        self._protocol = protocol
        
        self._url = "{protocol}://{host}:{port}".format(
            protocol=self._protocol, 
            host=self._host, 
            port=self._port
        )

    def authenticate(self, login, pwd):
        self._login, self._password = login, pwd
        service = auth.Connection(self._url)
        self._uid = service.authenticate(self._db, login, pwd, {})
        return self._uid



from setuptools import setup
from setuptools import find_packages

setup(name='odooapiclient',
      version='0.3',
      description='Odoo API Client',
      classifiers=[
          "Programming Language :: Python",
      ],
      author='Andrii Semko',
      author_email='semko.andrey.i@gmail.com',
      url='https://github.com/andriisem/odoo-api-python-client.git',
      packages=find_packages(),
)
